#!/bin/bash

#set -e
#Every script you write should include set -e at the top.
#This tells bash that it should exit the script if any statement returns a non-true return value. 
#The benefit of using -e is that it prevents errors snowballing into serious issues when they could have been caught earlier. 
#Again, for readability you may want to use set -o errexit.

uid=`echo "$UID"`;
if [ $uid -ne 0 ];then
	zenity --info --text="该程序每次以ROOT身份执行";
	exit;
fi;
SHUTDOWN="关机测试";
REBOOT="重启测试";
SUSPEND="待机测试";
SLEEP="休眠测试";
LIGHTDM_CONF=/etc/lightdm/lightdm.conf

usrname=${SUDO_USER}
echo $usrname
echo $usrname >/var/tmp/LogNames;


#echo "chmod 666 /sys/class/rtc/rtc0/wakealarm " >> /etc/rc.d/rc.local;

SELECTION=`zenity --list --radiolist --title="测试工具"  --text="选择您想操作的一项功能"  --column "" --column "请您选择" True "$SHUTDOWN"  Fasle "$REBOOT"   Fasle "$SUSPEND" Fasle "$SLEEP" `   

if [ -e $SELECTION ] ; then 
	exit;
fi

set_autologin(){
        autologin=$(grep 'autologin-user=' ${LIGHTDM_CONF})

        if [[ x${autologin} != x ]]; then
                # item found in LIGHTDM_CONF
                sed -i "s/.*autologin-user=.*/autologin-user=${usrname}/g" ${LIGHTDM_CONF}
        # lightdm.conf with SeatDefaults options
        else
                oldconf=$(grep '^\[SeatDefaults\]' ${LIGHTDM_CONF})
                newconf=$(grep '^\[Seat:.*\]' ${LIGHTDM_CONF})
                if [[ x${oldconf} != x ]]; then
                        sed -i "/^\[SeatDefaults\]/aautologin-user=${usrname}" ${LIGHTDM_CONF}
                elif [[ x${newconf} != x ]]; then
                        sed -i "/^\[Seat:.*\]/aautologin-user=${usrname}" ${LIGHTDM_CONF}
                else
                        zenity --error --text="未知的lightdm.conf格式"
                        exit 1
                fi
        fi
}


if [ "$SELECTION"  =  "$SHUTDOWN"  ] ;then

	set_autologin
 	TestNo=` zenity  --entry --text="请您输入需要关机测试的次数" `;
	if [ -e $TestNo ] ;then 
		exit 
	fi
	echo $TestNo > /var/tmp/LogBootNo;
	chmod 666  /var/tmp/LogBootNo;
	echo "$usrname ALL=(ALL:ALL) NOPASSWD:ALL" >>/etc/sudoers;
	BootTest.sh;
fi
if [ "$SELECTION"  =  "$REBOOT"  ]; then

	set_autologin
	
	#V7.0系统分区安装 当前boot下不存在引导文件
	if [ -e /boot/grub.cfg ] ; then 
		sed -i  "s/timeout=15/timeout=5/g" /boot/grub.cfg
		sed -i  "s/timeout 15/timeout 5/g" /boot/boot.cfg
		#sed -i  "s/timeout 15/timeout 5/g" /boot/boot.conf
	fi
	TestNo=` zenity  --entry --text="请您输入需要重启测试的次数" `;
	if [ -e $TestNo ] ;then 
		exit 
	fi
	echo $TestNo > /var/tmp/LogRebootNo;
	chmod 666 /var/tmp/LogRebootNo;
	echo "$usrname ALL=(ALL:ALL) NOPASSWD:ALL" >>/etc/sudoers;
	RebootTest.sh;
fi
if [ "$SELECTION" = "$SUSPEND"  ] ;then
	TestNo=` zenity  --entry --text="请您输入需要待机测试的次数" `;
	if [ -e $TestNo ] ;then 
		exit 
	fi
	echo $TestNo > /var/tmp/LogSuspendNo;
	chmod 666 /var/tmp/LogSuspendNo;
	SuspendTest.sh;
fi
if [ "$SELECTION"  =  "$SLEEP"  ] ;then
	TestNo=` zenity  --entry --text="请您输入需要休眠测试的次数" `;
	if [ -e $TestNo ] ;then 
		exit 
	fi
	echo $TestNo > /var/tmp/LogSleepNo;
	chmod 666 /var/tmp/LogSleepNo;
	SleepTest.sh;
fi
